#!/bin/bash
#SBATCH -p queue_name
#SBATCH -J rnaseq.star
#SBATCH -n 12
#SBATCH -t 168:00:00

module load gcc/7.2.0

thr=12
reference=$/path/to/reference/assembly.fasta
index=/path/to/star/index/output

# Generate an index of the reference genome
cmd=(
    STAR
    --runThreadN $thr
    --runMode genomeGenerate
    --genomeDir $index
    --genomeFastaFiles $reference
    --sjdbOverhang=MateLength-1
)
echo "${cmd[@]}"
"${cmd[@]}"

reads=/path/to/rnaseq/reads/directory
read1=$reads/rnaseq_reads.1.fq.gz
read2=$reads/rnaseq_reads.2.fq.gz
bam=/path/to/output/alignments.bam

# Align the raw RNA reads
cmd=(
    STAR
    --runThreadN $thr
    --runMode alignReads
    --outSAMtype BAM SortedByCoordinate
    --readFilesCommand zcat
    --genomeDir $index
    --readFilesIn $read1 $read2
    --outFileNamePrefix $bam
)
echo "${cmd[@]}"
"${cmd[@]}"
