#!/bin/bash
#SBATCH -p queue_name
#SBATCH -N 1
#SBATCH -n 8
#SBATCH -t 12:00:00
#SBATCH -J annot_blastp

module load gcc
thr=8

#
# Query information
#
# Path to query
query_p=/path/to/species_database/genome_annotations
cd $query_p
# Name of query
query_n=ceso.ftc
# Name of query protein fasta
query_fa=${query_p}/${query_n}/${query_n}.peptide.fa.gz

#
# Database information
#
# Path to database
database_p=/path/to/species_database/genome_annotations
# Name of database
database_n=cgun.ftc
# Database
dbase=${database_p}/${database_n}/${database_n}

#
# Output information
#
# Output path
output_p=/path/to/species_database/annotation_blasts
# Output name
output_n=blast_${query_n}_${database_n}.tsv.gz
echo -e "BLAST:\t${query_n}\t${database_n}"

# Run blastp
cmd=(
    blastp
    -query -
    -db $dbase
    -out -
    -evalue 0.001
    -outfmt 6
    -max_target_seqs 50
    -num_threads $thr
)

# Uncompress and run command
gunzip -c ${query_fa} | ${cmd[@]} | gzip > ${output_p}/${output_n}
